# Generated by Django 2.1.5 on 2019-02-22 16:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0012_partchangehistory'),
    ]

    operations = [
        migrations.AlterField(
            model_name='partchangehistory',
            name='part_id',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bom.Part'),
        ),
    ]



from django.core.exceptions import PermissionDenied
from django.urls import reverse
from django.http import HttpResponseRedirect
from social_django.models import UserSocialAuth


def google_authenticated(function):
    def wrap(request, *args, **kwargs):
        user = request.user
        try:
            user.social_auth.get(provider='google-oauth2')
            return function(request, *args, **kwargs)
        except UserSocialAuth.DoesNotExist as e:
            return HttpResponseRedirect(reverse('bom:settings', kwargs={'tab_anchor': 'file'}))

    wrap.__doc__ = function.__doc__
    wrap.__name__ = function.__name__
    return wrap
